/*###############################################################################
# Linux Management Providers (LMP), BIOS provider package
# Copyright (C) 2010 Guillaume BOTTEX, ETRI <guillaumebottex@etri.re.kr>
#
# This program is being developed under the "OpenDRIM" project.
# The "OpenDRIM" project web page: http://opendrim.sourceforge.net
# The "OpenDRIM" project mailing list: opendrim@googlegroups.com
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; version 2
# of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#################################################################################

#################################################################################
# To contributors, please leave your contact information in this section
# AND comment your changes in the source code.
#
# Modified by <Author(s)>, <Affiliation>, <Year>
###############################################################################*/

#ifndef OPENDRIM_BIOSSERVICE_H_
#define OPENDRIM_BIOSSERVICE_H_

#include <Instance.h>

const static char* OpenDRIM_BIOSService_classnames[] = {"OpenDRIM_BIOSService"};
static string OpenDRIM_BIOSService_NAMESPACE = _NAMESPACE;

class OpenDRIM_BIOSService {

public:
	
	string InstanceID;
	bool InstanceID_isNULL;
	
	string Caption;
	bool Caption_isNULL;
	
	string Description;
	bool Description_isNULL;
	
	string ElementName;
	bool ElementName_isNULL;
	
	string InstallDate;
	bool InstallDate_isNULL;
	
	vector<unsigned short> OperationalStatus;
	bool OperationalStatus_isNULL;
	
	vector<string> StatusDescriptions;
	bool StatusDescriptions_isNULL;
	
	string Status;
	bool Status_isNULL;
	
	unsigned short HealthState;
	bool HealthState_isNULL;
	
	unsigned short CommunicationStatus;
	bool CommunicationStatus_isNULL;
	
	unsigned short DetailedStatus;
	bool DetailedStatus_isNULL;
	
	unsigned short OperatingStatus;
	bool OperatingStatus_isNULL;
	
	unsigned short PrimaryStatus;
	bool PrimaryStatus_isNULL;
	
	unsigned short EnabledState;
	bool EnabledState_isNULL;
	
	string OtherEnabledState;
	bool OtherEnabledState_isNULL;
	
	unsigned short RequestedState;
	bool RequestedState_isNULL;
	
	unsigned short EnabledDefault;
	bool EnabledDefault_isNULL;
	
	string TimeOfLastStateChange;
	bool TimeOfLastStateChange_isNULL;
	
	vector<unsigned short> AvailableRequestedStates;
	bool AvailableRequestedStates_isNULL;
	
	unsigned short TransitioningToState;
	bool TransitioningToState_isNULL;
	
	string SystemCreationClassName;
	bool SystemCreationClassName_isNULL;
	
	string SystemName;
	bool SystemName_isNULL;
	
	string CreationClassName;
	bool CreationClassName_isNULL;
	
	string Name;
	bool Name_isNULL;
	
	string PrimaryOwnerName;
	bool PrimaryOwnerName_isNULL;
	
	string PrimaryOwnerContact;
	bool PrimaryOwnerContact_isNULL;
	
	string StartMode;
	bool StartMode_isNULL;
	
	bool Started;
	bool Started_isNULL;
	
	OpenDRIM_BIOSService() {
		InstanceID_isNULL = true;
		Caption_isNULL = true;
		Description_isNULL = true;
		ElementName_isNULL = true;
		InstallDate_isNULL = true;
		OperationalStatus_isNULL = true;
		StatusDescriptions_isNULL = true;
		Status_isNULL = true;
		HealthState_isNULL = true;
		CommunicationStatus_isNULL = true;
		DetailedStatus_isNULL = true;
		OperatingStatus_isNULL = true;
		PrimaryStatus_isNULL = true;
		EnabledState_isNULL = true;
		OtherEnabledState_isNULL = true;
		RequestedState_isNULL = true;
		EnabledDefault_isNULL = true;
		TimeOfLastStateChange_isNULL = true;
		AvailableRequestedStates_isNULL = true;
		TransitioningToState_isNULL = true;
		SystemCreationClassName_isNULL = true;
		SystemName_isNULL = true;
		CreationClassName_isNULL = true;
		Name_isNULL = true;
		PrimaryOwnerName_isNULL = true;
		PrimaryOwnerContact_isNULL = true;
		StartMode_isNULL = true;
		Started_isNULL = true;
	}
	
	~OpenDRIM_BIOSService() {}
	
	string getKeys() const {
		return CF_toLowCase(".SystemCreationClassName=\"" + CF_quoteString(SystemCreationClassName) + "\""".SystemName=\"" + CF_quoteString(SystemName) + "\""".CreationClassName=\"" + CF_quoteString(CreationClassName) + "\""".Name=\"" + CF_quoteString(Name) + "\"");
	}

	int getInstanceID(string& value) const {
		if (InstanceID_isNULL==true)
			return NOT_FOUND;
		value = InstanceID;
		return OK;
	}
	
	int setInstanceID(const string& newValue) {
		InstanceID = newValue;
		InstanceID_isNULL = false;
		return OK;
	}

	int getCaption(string& value) const {
		if (Caption_isNULL==true)
			return NOT_FOUND;
		value = Caption;
		return OK;
	}
	
	int setCaption(const string& newValue) {
		Caption = newValue;
		Caption_isNULL = false;
		return OK;
	}

	int getDescription(string& value) const {
		if (Description_isNULL==true)
			return NOT_FOUND;
		value = Description;
		return OK;
	}
	
	int setDescription(const string& newValue) {
		Description = newValue;
		Description_isNULL = false;
		return OK;
	}

	int getElementName(string& value) const {
		if (ElementName_isNULL==true)
			return NOT_FOUND;
		value = ElementName;
		return OK;
	}
	
	int setElementName(const string& newValue) {
		ElementName = newValue;
		ElementName_isNULL = false;
		return OK;
	}

	int getInstallDate(string& value) const {
		if (InstallDate_isNULL==true)
			return NOT_FOUND;
		value = InstallDate;
		return OK;
	}
	
	int setInstallDate(const string& newValue) {
		InstallDate = newValue;
		InstallDate_isNULL = false;
		return OK;
	}

	int getOperationalStatus(vector<unsigned short>& value) const {
		if (OperationalStatus_isNULL==true)
			return NOT_FOUND;
		value = OperationalStatus;
		return OK;
	}
	
	int setOperationalStatus(const vector<unsigned short>& newValue) {
		OperationalStatus = newValue;
		OperationalStatus_isNULL = false;
		return OK;
	}

	int getStatusDescriptions(vector<string>& value) const {
		if (StatusDescriptions_isNULL==true)
			return NOT_FOUND;
		value = StatusDescriptions;
		return OK;
	}
	
	int setStatusDescriptions(const vector<string>& newValue) {
		StatusDescriptions = newValue;
		StatusDescriptions_isNULL = false;
		return OK;
	}

	int getStatus(string& value) const {
		if (Status_isNULL==true)
			return NOT_FOUND;
		value = Status;
		return OK;
	}
	
	int setStatus(const string& newValue) {
		Status = newValue;
		Status_isNULL = false;
		return OK;
	}

	int getHealthState(unsigned short& value) const {
		if (HealthState_isNULL==true)
			return NOT_FOUND;
		value = HealthState;
		return OK;
	}
	
	int setHealthState(const unsigned short& newValue) {
		HealthState = newValue;
		HealthState_isNULL = false;
		return OK;
	}

	int getCommunicationStatus(unsigned short& value) const {
		if (CommunicationStatus_isNULL==true)
			return NOT_FOUND;
		value = CommunicationStatus;
		return OK;
	}
	
	int setCommunicationStatus(const unsigned short& newValue) {
		CommunicationStatus = newValue;
		CommunicationStatus_isNULL = false;
		return OK;
	}

	int getDetailedStatus(unsigned short& value) const {
		if (DetailedStatus_isNULL==true)
			return NOT_FOUND;
		value = DetailedStatus;
		return OK;
	}
	
	int setDetailedStatus(const unsigned short& newValue) {
		DetailedStatus = newValue;
		DetailedStatus_isNULL = false;
		return OK;
	}

	int getOperatingStatus(unsigned short& value) const {
		if (OperatingStatus_isNULL==true)
			return NOT_FOUND;
		value = OperatingStatus;
		return OK;
	}
	
	int setOperatingStatus(const unsigned short& newValue) {
		OperatingStatus = newValue;
		OperatingStatus_isNULL = false;
		return OK;
	}

	int getPrimaryStatus(unsigned short& value) const {
		if (PrimaryStatus_isNULL==true)
			return NOT_FOUND;
		value = PrimaryStatus;
		return OK;
	}
	
	int setPrimaryStatus(const unsigned short& newValue) {
		PrimaryStatus = newValue;
		PrimaryStatus_isNULL = false;
		return OK;
	}

	int getEnabledState(unsigned short& value) const {
		if (EnabledState_isNULL==true)
			return NOT_FOUND;
		value = EnabledState;
		return OK;
	}
	
	int setEnabledState(const unsigned short& newValue) {
		EnabledState = newValue;
		EnabledState_isNULL = false;
		return OK;
	}

	int getOtherEnabledState(string& value) const {
		if (OtherEnabledState_isNULL==true)
			return NOT_FOUND;
		value = OtherEnabledState;
		return OK;
	}
	
	int setOtherEnabledState(const string& newValue) {
		OtherEnabledState = newValue;
		OtherEnabledState_isNULL = false;
		return OK;
	}

	int getRequestedState(unsigned short& value) const {
		if (RequestedState_isNULL==true)
			return NOT_FOUND;
		value = RequestedState;
		return OK;
	}
	
	int setRequestedState(const unsigned short& newValue) {
		RequestedState = newValue;
		RequestedState_isNULL = false;
		return OK;
	}

	int getEnabledDefault(unsigned short& value) const {
		if (EnabledDefault_isNULL==true)
			return NOT_FOUND;
		value = EnabledDefault;
		return OK;
	}
	
	int setEnabledDefault(const unsigned short& newValue) {
		EnabledDefault = newValue;
		EnabledDefault_isNULL = false;
		return OK;
	}

	int getTimeOfLastStateChange(string& value) const {
		if (TimeOfLastStateChange_isNULL==true)
			return NOT_FOUND;
		value = TimeOfLastStateChange;
		return OK;
	}
	
	int setTimeOfLastStateChange(const string& newValue) {
		TimeOfLastStateChange = newValue;
		TimeOfLastStateChange_isNULL = false;
		return OK;
	}

	int getAvailableRequestedStates(vector<unsigned short>& value) const {
		if (AvailableRequestedStates_isNULL==true)
			return NOT_FOUND;
		value = AvailableRequestedStates;
		return OK;
	}
	
	int setAvailableRequestedStates(const vector<unsigned short>& newValue) {
		AvailableRequestedStates = newValue;
		AvailableRequestedStates_isNULL = false;
		return OK;
	}

	int getTransitioningToState(unsigned short& value) const {
		if (TransitioningToState_isNULL==true)
			return NOT_FOUND;
		value = TransitioningToState;
		return OK;
	}
	
	int setTransitioningToState(const unsigned short& newValue) {
		TransitioningToState = newValue;
		TransitioningToState_isNULL = false;
		return OK;
	}

	int getSystemCreationClassName(string& value) const {
		if (SystemCreationClassName_isNULL==true)
			return NOT_FOUND;
		value = SystemCreationClassName;
		return OK;
	}
	
	int setSystemCreationClassName(const string& newValue) {
		SystemCreationClassName = newValue;
		SystemCreationClassName_isNULL = false;
		return OK;
	}

	int getSystemName(string& value) const {
		if (SystemName_isNULL==true)
			return NOT_FOUND;
		value = SystemName;
		return OK;
	}
	
	int setSystemName(const string& newValue) {
		SystemName = newValue;
		SystemName_isNULL = false;
		return OK;
	}

	int getCreationClassName(string& value) const {
		if (CreationClassName_isNULL==true)
			return NOT_FOUND;
		value = CreationClassName;
		return OK;
	}
	
	int setCreationClassName(const string& newValue) {
		CreationClassName = newValue;
		CreationClassName_isNULL = false;
		return OK;
	}

	int getName(string& value) const {
		if (Name_isNULL==true)
			return NOT_FOUND;
		value = Name;
		return OK;
	}
	
	int setName(const string& newValue) {
		Name = newValue;
		Name_isNULL = false;
		return OK;
	}

	int getPrimaryOwnerName(string& value) const {
		if (PrimaryOwnerName_isNULL==true)
			return NOT_FOUND;
		value = PrimaryOwnerName;
		return OK;
	}
	
	int setPrimaryOwnerName(const string& newValue) {
		PrimaryOwnerName = newValue;
		PrimaryOwnerName_isNULL = false;
		return OK;
	}

	int getPrimaryOwnerContact(string& value) const {
		if (PrimaryOwnerContact_isNULL==true)
			return NOT_FOUND;
		value = PrimaryOwnerContact;
		return OK;
	}
	
	int setPrimaryOwnerContact(const string& newValue) {
		PrimaryOwnerContact = newValue;
		PrimaryOwnerContact_isNULL = false;
		return OK;
	}

	int getStartMode(string& value) const {
		if (StartMode_isNULL==true)
			return NOT_FOUND;
		value = StartMode;
		return OK;
	}
	
	int setStartMode(const string& newValue) {
		StartMode = newValue;
		StartMode_isNULL = false;
		return OK;
	}

	int getStarted(bool& value) const {
		if (Started_isNULL==true)
			return NOT_FOUND;
		value = Started;
		return OK;
	}
	
	int setStarted(const bool& newValue) {
		Started = newValue;
		Started_isNULL = false;
		return OK;
	}

};

class OpenDRIM_BIOSService_RequestStateChange_In {

public:

	unsigned short RequestedState;
	bool RequestedState_isNULL;

	Objectpath Job;
	bool Job_isNULL;

	string TimeoutPeriod;
	bool TimeoutPeriod_isNULL;

	OpenDRIM_BIOSService_RequestStateChange_In() {
		RequestedState_isNULL = true;
		Job_isNULL = true;
		TimeoutPeriod_isNULL = true;
	}

	~OpenDRIM_BIOSService_RequestStateChange_In() {}

	int getRequestedState(unsigned short& value) const {
		if (RequestedState_isNULL == true)
			return NOT_FOUND;
		value = RequestedState;
		return OK;
	}
	int setRequestedState(const unsigned short&  newValue) {
		RequestedState = newValue;
		RequestedState_isNULL = false;
		return OK;
	}

	int getJob(Objectpath& value) const {
		if (Job_isNULL == true)
			return NOT_FOUND;
		value = Job;
		return OK;
	}
	int setJob(const Objectpath&  newValue) {
		Job = newValue;
		Job_isNULL = false;
		return OK;
	}

	int getTimeoutPeriod(string& value) const {
		if (TimeoutPeriod_isNULL == true)
			return NOT_FOUND;
		value = TimeoutPeriod;
		return OK;
	}
	int setTimeoutPeriod(const string&  newValue) {
		TimeoutPeriod = newValue;
		TimeoutPeriod_isNULL = false;
		return OK;
	}

};

class OpenDRIM_BIOSService_RequestStateChange_Out {

public:

	Objectpath Job;
	bool Job_isNULL;

	OpenDRIM_BIOSService_RequestStateChange_Out() {
		Job_isNULL = true;
	}

	~OpenDRIM_BIOSService_RequestStateChange_Out() {}

	int getJob(Objectpath& value) const {
		if (Job_isNULL == true)
			return NOT_FOUND;
		value = Job;
		return OK;
	}
	int setJob(const Objectpath&  newValue) {
		Job = newValue;
		Job_isNULL = false;
		return OK;
	}

};

class OpenDRIM_BIOSService_SetBIOSAttribute_In {

public:

	Objectpath TargetBIOS;
	bool TargetBIOS_isNULL;

	string AttributeName;
	bool AttributeName_isNULL;

	vector<string> AttributeValue;
	bool AttributeValue_isNULL;

	string AuthorizationToken;
	bool AuthorizationToken_isNULL;

	unsigned int PasswordEncoding;
	bool PasswordEncoding_isNULL;

	unsigned int SetResult;
	bool SetResult_isNULL;

	OpenDRIM_BIOSService_SetBIOSAttribute_In() {
		TargetBIOS_isNULL = true;
		AttributeName_isNULL = true;
		AttributeValue_isNULL = true;
		AuthorizationToken_isNULL = true;
		PasswordEncoding_isNULL = true;
		SetResult_isNULL = true;
	}

	~OpenDRIM_BIOSService_SetBIOSAttribute_In() {}

	int getTargetBIOS(Objectpath& value) const {
		if (TargetBIOS_isNULL == true)
			return NOT_FOUND;
		value = TargetBIOS;
		return OK;
	}
	int setTargetBIOS(const Objectpath&  newValue) {
		TargetBIOS = newValue;
		TargetBIOS_isNULL = false;
		return OK;
	}

	int getAttributeName(string& value) const {
		if (AttributeName_isNULL == true)
			return NOT_FOUND;
		value = AttributeName;
		return OK;
	}
	int setAttributeName(const string&  newValue) {
		AttributeName = newValue;
		AttributeName_isNULL = false;
		return OK;
	}

	int getAttributeValue(vector<string>& value) const {
		if (AttributeValue_isNULL == true)
			return NOT_FOUND;
		value = AttributeValue;
		return OK;
	}
	int setAttributeValue(const vector<string>&  newValue) {
		AttributeValue = newValue;
		AttributeValue_isNULL = false;
		return OK;
	}

	int getAuthorizationToken(string& value) const {
		if (AuthorizationToken_isNULL == true)
			return NOT_FOUND;
		value = AuthorizationToken;
		return OK;
	}
	int setAuthorizationToken(const string&  newValue) {
		AuthorizationToken = newValue;
		AuthorizationToken_isNULL = false;
		return OK;
	}

	int getPasswordEncoding(unsigned int& value) const {
		if (PasswordEncoding_isNULL == true)
			return NOT_FOUND;
		value = PasswordEncoding;
		return OK;
	}
	int setPasswordEncoding(const unsigned int&  newValue) {
		PasswordEncoding = newValue;
		PasswordEncoding_isNULL = false;
		return OK;
	}

	int getSetResult(unsigned int& value) const {
		if (SetResult_isNULL == true)
			return NOT_FOUND;
		value = SetResult;
		return OK;
	}
	int setSetResult(const unsigned int&  newValue) {
		SetResult = newValue;
		SetResult_isNULL = false;
		return OK;
	}

};

class OpenDRIM_BIOSService_SetBIOSAttribute_Out {

public:

	unsigned int SetResult;
	bool SetResult_isNULL;

	OpenDRIM_BIOSService_SetBIOSAttribute_Out() {
		SetResult_isNULL = true;
	}

	~OpenDRIM_BIOSService_SetBIOSAttribute_Out() {}

	int getSetResult(unsigned int& value) const {
		if (SetResult_isNULL == true)
			return NOT_FOUND;
		value = SetResult;
		return OK;
	}
	int setSetResult(const unsigned int&  newValue) {
		SetResult = newValue;
		SetResult_isNULL = false;
		return OK;
	}

};

class OpenDRIM_BIOSService_SetBIOSAttributeEmbeddedInstance_In {

public:

	Objectpath TargetBIOS;
	bool TargetBIOS_isNULL;

	string AttributeConfig;
	bool AttributeConfig_isNULL;

	string AuthorizationToken;
	bool AuthorizationToken_isNULL;

	unsigned int PasswordEncoding;
	bool PasswordEncoding_isNULL;

	unsigned int SetResult;
	bool SetResult_isNULL;

	OpenDRIM_BIOSService_SetBIOSAttributeEmbeddedInstance_In() {
		TargetBIOS_isNULL = true;
		AttributeConfig_isNULL = true;
		AuthorizationToken_isNULL = true;
		PasswordEncoding_isNULL = true;
		SetResult_isNULL = true;
	}

	~OpenDRIM_BIOSService_SetBIOSAttributeEmbeddedInstance_In() {}

	int getTargetBIOS(Objectpath& value) const {
		if (TargetBIOS_isNULL == true)
			return NOT_FOUND;
		value = TargetBIOS;
		return OK;
	}
	int setTargetBIOS(const Objectpath&  newValue) {
		TargetBIOS = newValue;
		TargetBIOS_isNULL = false;
		return OK;
	}

	int getAttributeConfig(string& value) const {
		if (AttributeConfig_isNULL == true)
			return NOT_FOUND;
		value = AttributeConfig;
		return OK;
	}
	int setAttributeConfig(const string&  newValue) {
		AttributeConfig = newValue;
		AttributeConfig_isNULL = false;
		return OK;
	}

	int getAuthorizationToken(string& value) const {
		if (AuthorizationToken_isNULL == true)
			return NOT_FOUND;
		value = AuthorizationToken;
		return OK;
	}
	int setAuthorizationToken(const string&  newValue) {
		AuthorizationToken = newValue;
		AuthorizationToken_isNULL = false;
		return OK;
	}

	int getPasswordEncoding(unsigned int& value) const {
		if (PasswordEncoding_isNULL == true)
			return NOT_FOUND;
		value = PasswordEncoding;
		return OK;
	}
	int setPasswordEncoding(const unsigned int&  newValue) {
		PasswordEncoding = newValue;
		PasswordEncoding_isNULL = false;
		return OK;
	}

	int getSetResult(unsigned int& value) const {
		if (SetResult_isNULL == true)
			return NOT_FOUND;
		value = SetResult;
		return OK;
	}
	int setSetResult(const unsigned int&  newValue) {
		SetResult = newValue;
		SetResult_isNULL = false;
		return OK;
	}

};

class OpenDRIM_BIOSService_SetBIOSAttributeEmbeddedInstance_Out {

public:

	unsigned int SetResult;
	bool SetResult_isNULL;

	OpenDRIM_BIOSService_SetBIOSAttributeEmbeddedInstance_Out() {
		SetResult_isNULL = true;
	}

	~OpenDRIM_BIOSService_SetBIOSAttributeEmbeddedInstance_Out() {}

	int getSetResult(unsigned int& value) const {
		if (SetResult_isNULL == true)
			return NOT_FOUND;
		value = SetResult;
		return OK;
	}
	int setSetResult(const unsigned int&  newValue) {
		SetResult = newValue;
		SetResult_isNULL = false;
		return OK;
	}

};

class OpenDRIM_BIOSService_ReadRawBIOSData_In {

public:

	Objectpath TargetBIOS;
	bool TargetBIOS_isNULL;

	unsigned int Offset;
	bool Offset_isNULL;

	unsigned int NumberOfBytes;
	bool NumberOfBytes_isNULL;

	vector<unsigned char> Data;
	bool Data_isNULL;

	OpenDRIM_BIOSService_ReadRawBIOSData_In() {
		TargetBIOS_isNULL = true;
		Offset_isNULL = true;
		NumberOfBytes_isNULL = true;
		Data_isNULL = true;
	}

	~OpenDRIM_BIOSService_ReadRawBIOSData_In() {}

	int getTargetBIOS(Objectpath& value) const {
		if (TargetBIOS_isNULL == true)
			return NOT_FOUND;
		value = TargetBIOS;
		return OK;
	}
	int setTargetBIOS(const Objectpath&  newValue) {
		TargetBIOS = newValue;
		TargetBIOS_isNULL = false;
		return OK;
	}

	int getOffset(unsigned int& value) const {
		if (Offset_isNULL == true)
			return NOT_FOUND;
		value = Offset;
		return OK;
	}
	int setOffset(const unsigned int&  newValue) {
		Offset = newValue;
		Offset_isNULL = false;
		return OK;
	}

	int getNumberOfBytes(unsigned int& value) const {
		if (NumberOfBytes_isNULL == true)
			return NOT_FOUND;
		value = NumberOfBytes;
		return OK;
	}
	int setNumberOfBytes(const unsigned int&  newValue) {
		NumberOfBytes = newValue;
		NumberOfBytes_isNULL = false;
		return OK;
	}

	int getData(vector<unsigned char>& value) const {
		if (Data_isNULL == true)
			return NOT_FOUND;
		value = Data;
		return OK;
	}
	int setData(const vector<unsigned char>&  newValue) {
		Data = newValue;
		Data_isNULL = false;
		return OK;
	}

};

class OpenDRIM_BIOSService_ReadRawBIOSData_Out {

public:

	unsigned int NumberOfBytes;
	bool NumberOfBytes_isNULL;

	vector<unsigned char> Data;
	bool Data_isNULL;

	OpenDRIM_BIOSService_ReadRawBIOSData_Out() {
		NumberOfBytes_isNULL = true;
		Data_isNULL = true;
	}

	~OpenDRIM_BIOSService_ReadRawBIOSData_Out() {}

	int getNumberOfBytes(unsigned int& value) const {
		if (NumberOfBytes_isNULL == true)
			return NOT_FOUND;
		value = NumberOfBytes;
		return OK;
	}
	int setNumberOfBytes(const unsigned int&  newValue) {
		NumberOfBytes = newValue;
		NumberOfBytes_isNULL = false;
		return OK;
	}

	int getData(vector<unsigned char>& value) const {
		if (Data_isNULL == true)
			return NOT_FOUND;
		value = Data;
		return OK;
	}
	int setData(const vector<unsigned char>&  newValue) {
		Data = newValue;
		Data_isNULL = false;
		return OK;
	}

};

class OpenDRIM_BIOSService_WriteRawBIOSData_In {

public:

	Objectpath TargetBIOS;
	bool TargetBIOS_isNULL;

	unsigned int Offset;
	bool Offset_isNULL;

	unsigned int NumberOfBytes;
	bool NumberOfBytes_isNULL;

	vector<unsigned char> Data;
	bool Data_isNULL;

	string AuthorizationToken;
	bool AuthorizationToken_isNULL;

	unsigned int PasswordEncoding;
	bool PasswordEncoding_isNULL;

	OpenDRIM_BIOSService_WriteRawBIOSData_In() {
		TargetBIOS_isNULL = true;
		Offset_isNULL = true;
		NumberOfBytes_isNULL = true;
		Data_isNULL = true;
		AuthorizationToken_isNULL = true;
		PasswordEncoding_isNULL = true;
	}

	~OpenDRIM_BIOSService_WriteRawBIOSData_In() {}

	int getTargetBIOS(Objectpath& value) const {
		if (TargetBIOS_isNULL == true)
			return NOT_FOUND;
		value = TargetBIOS;
		return OK;
	}
	int setTargetBIOS(const Objectpath&  newValue) {
		TargetBIOS = newValue;
		TargetBIOS_isNULL = false;
		return OK;
	}

	int getOffset(unsigned int& value) const {
		if (Offset_isNULL == true)
			return NOT_FOUND;
		value = Offset;
		return OK;
	}
	int setOffset(const unsigned int&  newValue) {
		Offset = newValue;
		Offset_isNULL = false;
		return OK;
	}

	int getNumberOfBytes(unsigned int& value) const {
		if (NumberOfBytes_isNULL == true)
			return NOT_FOUND;
		value = NumberOfBytes;
		return OK;
	}
	int setNumberOfBytes(const unsigned int&  newValue) {
		NumberOfBytes = newValue;
		NumberOfBytes_isNULL = false;
		return OK;
	}

	int getData(vector<unsigned char>& value) const {
		if (Data_isNULL == true)
			return NOT_FOUND;
		value = Data;
		return OK;
	}
	int setData(const vector<unsigned char>&  newValue) {
		Data = newValue;
		Data_isNULL = false;
		return OK;
	}

	int getAuthorizationToken(string& value) const {
		if (AuthorizationToken_isNULL == true)
			return NOT_FOUND;
		value = AuthorizationToken;
		return OK;
	}
	int setAuthorizationToken(const string&  newValue) {
		AuthorizationToken = newValue;
		AuthorizationToken_isNULL = false;
		return OK;
	}

	int getPasswordEncoding(unsigned int& value) const {
		if (PasswordEncoding_isNULL == true)
			return NOT_FOUND;
		value = PasswordEncoding;
		return OK;
	}
	int setPasswordEncoding(const unsigned int&  newValue) {
		PasswordEncoding = newValue;
		PasswordEncoding_isNULL = false;
		return OK;
	}

};

class OpenDRIM_BIOSService_WriteRawBIOSData_Out {

public:

	unsigned int NumberOfBytes;
	bool NumberOfBytes_isNULL;

	OpenDRIM_BIOSService_WriteRawBIOSData_Out() {
		NumberOfBytes_isNULL = true;
	}

	~OpenDRIM_BIOSService_WriteRawBIOSData_Out() {}

	int getNumberOfBytes(unsigned int& value) const {
		if (NumberOfBytes_isNULL == true)
			return NOT_FOUND;
		value = NumberOfBytes;
		return OK;
	}
	int setNumberOfBytes(const unsigned int&  newValue) {
		NumberOfBytes = newValue;
		NumberOfBytes_isNULL = false;
		return OK;
	}

};

class OpenDRIM_BIOSService_SetBIOSAttributes_In {

public:

	Objectpath TargetBIOS;
	bool TargetBIOS_isNULL;

	string CollectionElementName;
	bool CollectionElementName_isNULL;

	vector<string> AttributeName;
	bool AttributeName_isNULL;

	vector<string> AttributeValue;
	bool AttributeValue_isNULL;

	string AuthorizationToken;
	bool AuthorizationToken_isNULL;

	unsigned int PasswordEncoding;
	bool PasswordEncoding_isNULL;

	vector<unsigned int> SetResult;
	bool SetResult_isNULL;

	OpenDRIM_BIOSService_SetBIOSAttributes_In() {
		TargetBIOS_isNULL = true;
		CollectionElementName_isNULL = true;
		AttributeName_isNULL = true;
		AttributeValue_isNULL = true;
		AuthorizationToken_isNULL = true;
		PasswordEncoding_isNULL = true;
		SetResult_isNULL = true;
	}

	~OpenDRIM_BIOSService_SetBIOSAttributes_In() {}

	int getTargetBIOS(Objectpath& value) const {
		if (TargetBIOS_isNULL == true)
			return NOT_FOUND;
		value = TargetBIOS;
		return OK;
	}
	int setTargetBIOS(const Objectpath&  newValue) {
		TargetBIOS = newValue;
		TargetBIOS_isNULL = false;
		return OK;
	}

	int getCollectionElementName(string& value) const {
		if (CollectionElementName_isNULL == true)
			return NOT_FOUND;
		value = CollectionElementName;
		return OK;
	}
	int setCollectionElementName(const string&  newValue) {
		CollectionElementName = newValue;
		CollectionElementName_isNULL = false;
		return OK;
	}

	int getAttributeName(vector<string>& value) const {
		if (AttributeName_isNULL == true)
			return NOT_FOUND;
		value = AttributeName;
		return OK;
	}
	int setAttributeName(const vector<string>&  newValue) {
		AttributeName = newValue;
		AttributeName_isNULL = false;
		return OK;
	}

	int getAttributeValue(vector<string>& value) const {
		if (AttributeValue_isNULL == true)
			return NOT_FOUND;
		value = AttributeValue;
		return OK;
	}
	int setAttributeValue(const vector<string>&  newValue) {
		AttributeValue = newValue;
		AttributeValue_isNULL = false;
		return OK;
	}

	int getAuthorizationToken(string& value) const {
		if (AuthorizationToken_isNULL == true)
			return NOT_FOUND;
		value = AuthorizationToken;
		return OK;
	}
	int setAuthorizationToken(const string&  newValue) {
		AuthorizationToken = newValue;
		AuthorizationToken_isNULL = false;
		return OK;
	}

	int getPasswordEncoding(unsigned int& value) const {
		if (PasswordEncoding_isNULL == true)
			return NOT_FOUND;
		value = PasswordEncoding;
		return OK;
	}
	int setPasswordEncoding(const unsigned int&  newValue) {
		PasswordEncoding = newValue;
		PasswordEncoding_isNULL = false;
		return OK;
	}

	int getSetResult(vector<unsigned int>& value) const {
		if (SetResult_isNULL == true)
			return NOT_FOUND;
		value = SetResult;
		return OK;
	}
	int setSetResult(const vector<unsigned int>&  newValue) {
		SetResult = newValue;
		SetResult_isNULL = false;
		return OK;
	}

};

class OpenDRIM_BIOSService_SetBIOSAttributes_Out {

public:

	vector<unsigned int> SetResult;
	bool SetResult_isNULL;

	OpenDRIM_BIOSService_SetBIOSAttributes_Out() {
		SetResult_isNULL = true;
	}

	~OpenDRIM_BIOSService_SetBIOSAttributes_Out() {}

	int getSetResult(vector<unsigned int>& value) const {
		if (SetResult_isNULL == true)
			return NOT_FOUND;
		value = SetResult;
		return OK;
	}
	int setSetResult(const vector<unsigned int>&  newValue) {
		SetResult = newValue;
		SetResult_isNULL = false;
		return OK;
	}

};

#endif /*OPENDRIM_BIOSSERVICE_H_*/
